@@ -8,18 +8,15 @@
 #		st_cast(p0, "POLYGON")
 # }
 
-check_spatstat <- function(pkg, X = NULL){
-  if(!requireNamespace(pkg, quietly = TRUE)){
-    stop("package ", pkg, " required, please install it (or the full spatstat package) first")
-  } else{
-    spst_ver <- try(packageVersion("spatstat"), silent = TRUE)
-    if(!inherits(spst_ver, "try-error") && spst_ver < 2.0-0){
-      stop("You have an old version of spatstat installed which is incompatible with ", pkg, 
-           ". Please update spatstat (or uninstall it).")
-    }
-  }
-  if (!is.null(X) && isTRUE(st_is_longlat(X)))
-    stop("Only projected coordinates may be converted to spatstat class objects")
+check_spatstat <- function(pkg, X = NULL) {
+	if (!requireNamespace(pkg, quietly = TRUE))
+		stop("package ", pkg, " required, please install it (or the full spatstat package) first")
+	spst_ver <- try(packageVersion("spatstat"), silent = TRUE)
+	if (!inherits(spst_ver, "try-error") && spst_ver < 2.0-0)
+		stop("You have an old version of spatstat installed which is incompatible with ", pkg, 
+			". Please update spatstat (or uninstall it).")
+	if (!is.null(X) && isTRUE(st_is_longlat(X)))
+		stop("Only projected coordinates may be converted to spatstat class objects", call. = FALSE)
 }
 
 #' @name st_as_sf
@@ -31,32 +28,39 @@ check_spatstat <- function(pkg, X = NULL){
 #'   g[st_is(g, "POINT"),]
 #' }
 st_as_sf.ppp = function(x, ...) {
-  check_spatstat("spatstat.geom")
-  # window:
-  win = st_sf(label = "window", geom = st_as_sfc(spatstat.geom::as.owin(x)))
+	check_spatstat("spatstat.geom")
+	# window:
+	win = st_sf(label = "window", geom = st_as_sfc(spatstat.geom::as.owin(x)))
 
-  # points:
-  m = as.matrix(data.frame(x$x, x$y))
-  pointwork = st_sfc(lapply(seq_len(NROW(m)), function(i) st_point(m[i,])))
-  points_sf = st_sf(label = rep("point", NROW(m)), geom = pointwork)
+	# points:
+	m = as.matrix(data.frame(x$x, x$y))
+	pointwork = st_sfc(lapply(seq_len(NROW(m)), function(i) st_point(m[i,])))
+	points_sf = st_sf(label = rep("point", NROW(m)), geom = pointwork)
 
-  # merge window and points:
-  ret = rbind(win, points_sf)
-  if (spatstat.geom::is.marked(x)) {
-	# add marks:
-    m = as.data.frame(spatstat.geom::marks(x))
-	cbind.sf(ret, m[c(NA, seq_len(nrow(m))),])
-  } else
-  	ret
+	# merge window and points:
+	ret = rbind(win, points_sf)
+	if (spatstat.geom::is.marked(x)) {
+		# add marks:
+		m = as.data.frame(spatstat.geom::marks(x))
+		cbind.sf(m[c(NA, seq_len(nrow(m))), , drop = FALSE], ret)
+	} else
+		ret
+}
+
+#' @export
+st_as_sf.ppplist = function(x, ...) {
+	w = st_geometry(st_as_sf(x[[1]]))[1]
+	sim = st_sfc(lapply(x, function(p) do.call(c, st_geometry(st_as_sf(p))[-1])))
+	st_sf(label = c("window", names(x)), geom = c(w, sim))
 }
 
 
 #' @name st_as_sf
 #' @export
 st_as_sf.psp = function(x, ...) {
-  check_spatstat("spatstat.geom")
+	check_spatstat("spatstat.geom")
 	# line segments:
- 	m = as.matrix(x$ends)
+	m = as.matrix(x$ends)
 	lst1 = lapply(seq_len(NROW(m)), function(i) st_linestring(matrix(m[i,], 2, byrow = TRUE)))
 
 	# window:
@@ -66,7 +70,7 @@ st_as_sf.psp = function(x, ...) {
 	ret = st_sf(label = label, geom = st_sfc(c(list(win), lst1)))
 	if (spatstat.geom::is.marked(x)) { # add marks:
 		m = as.data.frame(spatstat.geom::marks(x))
-		cbind.sf(ret, m[c(NA, seq_len(nrow(m))),])
+		cbind.sf(m[c(NA, seq_len(nrow(m))), , drop = FALSE], ret)
 	} else
 		ret
 }
@@ -93,7 +97,7 @@ st_as_sfc.psp <- function(x, ...) {
 #'  plot(st_as_sf(chicago)[-1,"label"])
 #' }
 st_as_sf.lpp = function(x, ...) {
-  check_spatstat("spatstat.linnet")
+	check_spatstat("spatstat.linnet")
 	# lines, polygon:
 	linework_sf = st_as_sf(spatstat.geom::as.psp(spatstat.geom::domain(x)))
 	# points:
@@ -107,25 +111,27 @@ st_as_sf.lpp = function(x, ...) {
 
 # as.ppp etc methods: from maptools/pkg/R/spatstat1.R
 
-as.ppp.sfc = function(X) {
-  check_spatstat("spatstat.geom", X)
+as.ppp.sfc = function(X, W = NULL, ...) {
+	check_spatstat("spatstat.geom", X)
 	d = st_dimension(X)
-	if (d[1] == 2 && all(d[-1] == 0)) {
-		W = spatstat.geom::as.owin(X[1])
-		X = X[-1]
-		check = TRUE
-	} else if (all(d == 0)) { # no window in first feature geometry:
-		bb <- st_bbox(X)
-		W = spatstat.geom::owin(bb[c("xmin", "xmax")], bb[c("ymin", "ymax")])
-		check = FALSE
-	} else
-		stop("sfc object does not consist of points, or a window followed by points")
+	if (is.null(W)) {
+		if (d[1] == 2 && all(d[-1] == 0)) {
+			W = spatstat.geom::as.owin(X[1])
+			X = X[-1]
+			check = TRUE
+		} else if (all(d == 0)) { # no window in first feature geometry:
+			bb <- st_bbox(X)
+			W = spatstat.geom::owin(bb[c("xmin", "xmax")], bb[c("ymin", "ymax")])
+			check = FALSE
+		} else
+			stop("sfc object does not consist of points, or a window followed by points")
+	}
 	cc = st_coordinates(X)
 	spatstat.geom::ppp(cc[,1], cc[,2], window = W, marks = NULL, check = check)
 }
 
 as.ppp.sf = function(X) {
-  check_spatstat("spatstat.geom", X)
+	check_spatstat("spatstat.geom", X)
 	pp = spatstat.geom::as.ppp(st_geometry(X))
 	if (st_dimension(X[1,]) == 2)
 		X = X[-1,]
@@ -140,7 +146,7 @@ as.ppp.sf = function(X) {
 }
 
 as.owin.POLYGON = function(W, ..., fatal, check_polygons = TRUE) {
-  check_spatstat("spatstat.geom", W)
+	check_spatstat("spatstat.geom", W)
 	if (check_polygons)
 		W = check_ring_dir(W)
 	bb = st_bbox(W)
@@ -148,7 +154,7 @@ as.owin.POLYGON = function(W, ..., fatal, check_polygons = TRUE) {
 }
 
 as.owin.MULTIPOLYGON = function(W, ..., fatal, check_polygons = TRUE) {
-  check_spatstat("spatstat.geom", W)
+	check_spatstat("spatstat.geom", W)
 	if (check_polygons)
 		W = check_ring_dir(W)
 	bb = st_bbox(W)
@@ -186,8 +192,8 @@ as.owin.sf = function(W, ...) {
 #' @export
 st_as_sfc.owin = function(x, ...) {
 # FROM: methods for coercion to Spatial Polygons by Adrian Baddeley, pkg maptools
-  check_spatstat("spatstat.geom")
-  x <- spatstat.geom::as.polygonal(x)
+	check_spatstat("spatstat.geom")
+	x <- spatstat.geom::as.polygonal(x)
 	closering <- function(df) { df[c(seq(nrow(df)), 1), ] }
 	pieces <- lapply(x$bdry,
 		function(p) st_polygon(list(closering(cbind(p$x,p$y)))))
@@ -214,8 +220,8 @@ st_as_sf.owin = function(x, ...) {
 
 #' @export
 st_as_sfc.tess <- function(x, ...) {
-  check_spatstat("spatstat.geom")
-  stopifnot(spatstat.geom::is.tess(x))
+	check_spatstat("spatstat.geom")
+	stopifnot(spatstat.geom::is.tess(x))
 	y <- spatstat.geom::tiles(x)
 	nam <- names(y)
 	z <- list()
@@ -225,14 +231,14 @@ st_as_sfc.tess <- function(x, ...) {
 			warning(paste("tile", i, "defective\n", as.character(zi)))
 		else
 			z[[i]] <- zi
-    }
+	}
 	do.call(c, z)
 }
 
 # methods for 'as.psp' for sp classes by Adrian Baddeley
 as.psp.LINESTRING <- function(from, ..., window=NULL, marks=NULL, fatal) {
-  check_spatstat("spatstat.geom")
-  xy <- unclass(from)
+	check_spatstat("spatstat.geom")
+	xy <- unclass(from)
 	df <- as.data.frame(cbind(xy[-nrow(xy), , drop=FALSE], xy[-1, , drop=FALSE]))
 	if (is.null(window)) {
 		xrange <- range(xy[,1])
@@ -243,9 +249,9 @@ as.psp.LINESTRING <- function(from, ..., window=NULL, marks=NULL, fatal) {
 }
 
 as.psp.MULTILINESTRING <- function(from, ..., window=NULL, marks=NULL, fatal) {
-  check_spatstat("spatstat.geom")
-  y <- lapply(from, as.psp.LINESTRING, window=window)
-    z <- do.call(spatstat.geom::superimpose,c(y,list(W=window)))
+	check_spatstat("spatstat.geom")
+	y <- lapply(from, as.psp.LINESTRING, window=window)
+	z <- do.call(spatstat.geom::superimpose,c(y,list(W=window)))
 	if(!is.null(marks))
 		spatstat.geom::setmarks(z, marks)
 	else
@@ -253,16 +259,16 @@ as.psp.MULTILINESTRING <- function(from, ..., window=NULL, marks=NULL, fatal) {
 }
 
 as.psp.sfc_MULTILINESTRING <- function(from, ..., window=NULL, marks=NULL,
-                                 characterMarks=FALSE, fatal) {
-  check_spatstat("spatstat.geom", from)
-  
+			characterMarks=FALSE, fatal) {
+
+	check_spatstat("spatstat.geom", from)
 	if(is.null(window)) {
 		bb = st_bbox(from)
 		window = spatstat.geom::owin(bb[c("xmin", "xmax")], bb[c("ymin", "ymax")]) 
 	}
 	lin <- unclass(from)
 	y <- lapply(lin, as.psp.MULTILINESTRING, window=window)
-    z <- do.call(spatstat.geom::superimpose, c(y, list(W = window)))
+	z <- do.call(spatstat.geom::superimpose, c(y, list(W = window)))
 	if(!is.null(marks))
 		spatstat.geom::setmarks(z, marks)
 	else
@@ -274,8 +280,8 @@ as.psp.sfc = function(from, ...) {
 }
 
 as.psp.sf <- function(from, ..., window=NULL, marks=NULL, fatal) {
-  check_spatstat("spatstat.geom", from)
-  
+	check_spatstat("spatstat.geom", from)
+
 	y <- st_geometry(from)
 	if (!inherits(y, "sfc_MULTILINESTRING"))
 		stop("geometries should be of type LINESTRING")
